---
title: جزئیات
---

یک کامپوننت داخلی برای نمایش محتوای قابل باز و بسته شدن.

<!--more-->

## مثال

{{% details title="جزئیات" %}}

این محتوای جزئیات است.

مارک‌داون **پشتیبانی می‌شود**.

{{% /details %}}

{{% details title="برای نمایش روی من کلیک کنید" closed="true" %}}

این به طور پیش‌فرض پنهان می‌شود.

{{% /details %}}

## استفاده

````markdown
{{%/* details title="جزئیات" */%}}

این محتوای جزئیات است.

مارک‌داون **پشتیبانی می‌شود**.

{{%/* /details */%}}
````

````markdown
{{%/* details title="برای نمایش روی من کلیک کنید"closed="true" */%}}

این به طور پیش‌فرض پنهان می‌شود.

{{%/* /details */%}}
````
